@@ -4,13 +4,13 @@ import time
 from celery.exceptions import TaskRevokedError
 
 import dagster._check as check
-from dagster.core.errors import DagsterSubprocessError
-from dagster.core.events import DagsterEvent, EngineEventData
-from dagster.core.execution.context.system import PlanOrchestrationContext
-from dagster.core.execution.plan.plan import ExecutionPlan
-from dagster.core.storage.tags import PRIORITY_TAG
-from dagster.serdes import deserialize_json_to_dagster_namedtuple
-from dagster.utils.error import serializable_error_info_from_exc_info
+from dagster._core.errors import DagsterSubprocessError
+from dagster._core.events import DagsterEvent, EngineEventData
+from dagster._core.execution.context.system import PlanOrchestrationContext
+from dagster._core.execution.plan.plan import ExecutionPlan
+from dagster._core.storage.tags import PRIORITY_TAG
+from dagster._serdes import deserialize_json_to_dagster_namedtuple
+from dagster._utils.error import serializable_error_info_from_exc_info
 
 from .defaults import task_default_priority, task_default_queue
 from .make_app import make_app
